ssa: ggstride

View source: R/ssa.R

ssaR Documentation

ggstride

Description

ssa() returns a data frame that contains residue identifiers (resname_chain_resid; e.g., MET_A_1) as column names and STRIDE assignments of each residue as each row for each frame of the trajectory.

Usage

ssa(pdb, traj, start = 1, last = nrow(traj))

Arguments

pdb:

the pdb file including same atoms with the trajectory. bio3d::read.pdb() should be used to read.

traj:

the trajectory file, xyz format of bio3d should be used. It could be any type of trajectory supported by bio3d.

start:

(default = 1) the number of first frame you want to analyze

last:

(default = number of frames in your trajectory) the number of last frame you want to analyze

Value

dataframe

Examples

pdb_WT <- read.pdb("example/wt.pdb")
dcd_WT <- read.dcd(trjfile = "example/wt.dcd")
ssa_WT <- ssa(pdb_WT, dcd_WT)

package::ssa(pdb, traj, start = 1, last = nrow(traj))


ugerlevik/ggstride documentation built on Feb. 7, 2023, 11:13 a.m.