ssa.pdb: ggstride

View source: R/ssa.pdb.R

ssa.pdbR Documentation

ggstride

Description

ssa.pdb() returns a data frame that contains residue identifiers (resname_chain_resid; e.g., MET_A_1) as column names and STRIDE assignments of each residue as the row

Usage

ssa.pdb(pdb)

Arguments

pdb:

the pdb file including same atoms with the trajectory. bio3d::read.pdb() should be used to read.

Value

dataframe

Examples

pdb <- read.pdb("example/wt.pdb")
ssa_df <- ssa.pdb(pdb)

package::ssa(pdb)


ugerlevik/ggstride documentation built on Feb. 7, 2023, 11:13 a.m.