| ssa.pdb | R Documentation |
ssa.pdb() returns a data frame that contains residue identifiers (resname_chain_resid; e.g., MET_A_1) as column names and STRIDE assignments of each residue as the row
ssa.pdb(pdb)
pdb: |
the pdb file including same atoms with the trajectory. bio3d::read.pdb() should be used to read. |
dataframe
pdb <- read.pdb("example/wt.pdb")
ssa_df <- ssa.pdb(pdb)
package::ssa(pdb)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.